@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: attoparsec
 version: 0.13.0.1
-id: attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
-key: attop_J9KpGVXXisl2SCx1ugNrAd
+id: attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+key: attop_5BMY90empToJCYpnsukIZC
 license: BSD3
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
 stability: experimental
@@ -33,14 +33,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/attoparsec-0.13.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/attoparsec-0.13.0.1
-hs-libraries: HSattoparsec-0.13.0.1-J9KpGVXXisl2SCx1ugNrAd
+hs-libraries: HSattoparsec-0.13.0.1-5BMY90empToJCYpnsukIZC
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    scientific-0.3.4.5-648b7dc78cf09ce28c222dfd7438d54f
+    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
